;; Generated package description from cond-star.el  -*- no-byte-compile: t -*-
(define-package "cond-star" "1.0.0.20251108.104352" "Extended form of `cond' construct" '((emacs "24.3")) :commit "ef2584585b095fff1e045e58673d2a7c8f9af799" :url "https://elpa.gnu.org/packages/cond-star.html" :maintainer '("Richard Stallman" . "rms@gnu.org"))
